@@ -131,7 +131,8 @@ static void reportConflict(
 /// to be deduplicated and checked for conflicts.
 /// \param[in] SM SourceManager required for conflict reporting.
 ///
-/// \returns \li true if conflicts were detected
+/// \returns \parblock
+///          \li true if conflicts were detected
 ///          \li false if no conflicts were detected
 static bool deduplicateAndDetectConflicts(FileToReplacementsMap &Replacements,
                                           SourceManager &SM) {
@@ -183,10 +184,7 @@ bool mergeAndDeduplicate(const TUReplacements &TUs,
   }
 
   // Ask clang to deduplicate and report conflicts.
-  if (deduplicateAndDetectConflicts(GroupedReplacements, SM))
-    return false;
-
-  return true;
+  return !deduplicateAndDetectConflicts(GroupedReplacements, SM);
 }
 
 bool applyReplacements(const FileToReplacementsMap &GroupedReplacements,
@@ -211,14 +209,11 @@ RangeVector calculateChangedRanges(
   RangeVector ChangedRanges;
 
   // Generate the new ranges from the replacements.
-  //
-  // NOTE: This is O(n^2) in the number of replacements. If this starts to
-  // become a problem inline shiftedCodePosition() here and do shifts in a
-  // single run through this loop.
+  int Shift = 0;
   for (const tooling::Replacement &R : Replaces) {
-    unsigned Offset = tooling::shiftedCodePosition(Replaces, R.getOffset());
+    unsigned Offset = R.getOffset() + Shift;
     unsigned Length = R.getReplacementText().size();
-
+    Shift += Length - R.getLength();
     ChangedRanges.push_back(tooling::Range(Offset, Length));
   }
 
